sqlcount = 44

##########################################################################
# Non dbms specific repository creation script. 
# Processed by TrelliSoft.install.RepositoryInstall
# 
# This file must have the following format:
# 1) The first line of the file must contain a count of the sql stmts
#    included in the line. This info is used to update a progress bar
#    as the sql file is being processed. This line should be in the
#    format:
#        sqlcount = <n>
#    where <n> represents the # of statements contained in the file
#
# 2) Each sql statement must be terminated by a ';' as the first char
#    of a new line. Everything else on the terminator line is ignored.
#
# 3) Comments are denoted by a '#' as the first char of a line. Everything
#    on a comment line is ignored
#
# Parameter Values (see TrelliSoft.install.RepositoryInstall for all DBs):
#
# Parm    Oracle Value        MSSQL Value
# ----    -----------------   ----------------------------------
# {0}     decimal(10)         integer
# {1}     decimal(5)          smallint
# {2}     raw(20)             varbinary(20)
# {3}     date                datetime
# {4}     long                text    
# {5}     long raw            image   
# {6}     <empty>             case_mask varbinary(8) default 0x00 not null,
# {7}     <empty>             case_mask varbinary(64) default 0x00 not null,
# {8}     sysdate             current_timestamp
# {9}     '20'                ' '
# {10}    <empty>             , case_mask
# {11}    <empty>             0x00,
# {12}    float               float
# {13}    raw(60)             varbinary(60)
# {14}    <empty>             t_res_stat_dir.
###########################################################################

create table t_res_rdbms
  (rdbms_id           {0}             not null,
   computer_id        {0}             not null,
   rdbms_version      varchar(10)     not null,
   rdbms_type         char(1)         not null,
   rdbms_name         varchar(128)    not null,
   rdbms_home         {23}    not null,
   rdbms_port         {0}             not null,
   rdbms_login        varchar(128)    not null,
   rdbms_password     varchar(128)    not null,
   last_start_time    {3}             not null,
   last_probe_time    {3}             not null,
   probe_status       char(1)         not null) {22} 
;


create table t_res_database
  (rdbms_id           {0}             not null,
   database_id        {0}             not null,
   owner_id           {0}             not null,
   dbid               decimal(13)     not null,
   group_id           {0}             not null,
   name               varchar(128)    not null,
   block_size         {0}             not null,
   log_mode           char(1)         not null,
   status             char(1)         not null,
   max_instances      {1}             not null,
   tablespaces        {0}             not null,
   max_datafiles      {0}             not null,
   datafiles          {0}             not null,
   max_logfiles       {1}             not null,
   logfiles           {1}             not null,
   total_size         decimal(13)     not null,
   capacity           decimal(13)     not null,
   freespace          decimal(13)     not null,
   create_time        {3}             not null,
   discover_time      {3}             not null,
   remove_time        {3}             not null) {22} 
;


create table t_res_tablespace
  (database_id        {0}             not null,
   owner_id           {0}             not null,
   tablespace_id      {0}             not null,
   group_id           {0}             not null,
   oid                {0}             not null,
   data_files         {1}             not null,
   name               varchar(128)    not null,
   status             char(1)         not null,
   temporary_ts       char(1)         not null,
   table_count        {0}             not null,
   index_count        {0}             not null,
   other_count        {0}             not null,
   unused_space       decimal(13)     not null,
   min_extent_size    {0}             not null,
   initial_extent     {0}             not null,
   next_extent        {0}             not null,
   min_extents        {0}             not null,
   max_extents        {0}             not null,
   pct_increase       {1}             not null,
   logging            char(1)         not null,
   total_size         decimal(13)     not null,
   freespace          decimal(13)     not null,
   free_extents       {0}             not null,
   coalesced_extents  {0}             not null,
   min_free_extent    {0}             not null,
   max_free_extent    {0}             not null,
   scan_time          {3}             not null,
   discover_time      {3}             not null,
   removed_time       {3}             not null) {22} 
;


create table t_res_datafile
  (tablespace_id      {0}             not null,
   file_id            {0}             not null,
   oid                {0}             not null,
   name               {23}    not null,
   status             char(1)         not null,
   autoextend         char(1)         not null,
   max_size           {0}             not null,
   file_type          char(1)         not null,
   filesystem_id      {0}             not null,
   total_size         {0}             not null,
   freespace          {0}             not null,
   free_extents       {0}             not null,
   coalesced_extents  {0}             not null,
   min_free_extent    {0}             not null,
   max_free_extent    {0}             not null,
   create_time        {3}             not null,
   discover_time      {3}             not null) {22} 
;


create table t_res_log_group
  (id                 {0}             not null,
   database_id        {0}             not null,
   group_id           {0}             not null,
   sequence           {0}             not null,
   status             char(1)         not null,
   archived           char(1)         not null,
   log_size           {0}             not null) {22} 
;
   

create table t_res_logfile
  (logfile_id         {0}             not null,
   database_id        {0}             not null,
   group_id           {0}             not null,
   filesystem_id      {0}             not null,
   name               {23}    not null,
   file_type          char(1)         not null) {22} 
;


create table t_res_controlfile
  (controlfile_id     {0}             not null,
   database_id        {0}             not null,
   name               {23}    not null,
   filesystem_id      {0}             not null,
   file_size          {0}             not null) {22} 
;
   
   
create table t_res_arch_log_dir
  (directory_id       {0}             not null,
   database_id        {0}             not null,
   dest_id            {0}             not null,
   name               {23}    not null,
   status             char(1)         not null,
   filesystem_id      {0}             not null,
   file_count         {0}             not null,
   file_size          {0}             not null,
   failure_time       {3}             not null) {22} 
;


create table t_stat_table
  (statistic_id       {0}             not null,
   tablespace_id      {0}             not null,  
   creator_id         {0}             not null,
   name               varchar(128)    not null,
   statistic_type     char(1)         not null,
   table_type         char(1)         not null,
   partitions         {1}             not null,
   indexes            {1}             not null,
   segments           {1}             not null,
   extents            {0}             not null,
   pct_free           {1}             not null,
   pct_used           {1}             not null,
   ini_transactions   {1}             not null,
   max_transactions   {1}             not null,
   initial_extent     {0}             not null,
   next_extent        {0}             not null,
   min_extents        {0}             not null,
   max_extents        {0}             not null,
   pct_increase       {1}             not null,
   total_size         decimal(13)     not null,
   unused_space       decimal(13)     not null,
   index_size         decimal(13)     not null,
   freelist_blocks    {0}             not null,
   analyze_time       {3}             not null,
   number_analyzed    {1}             not null,
   user_stats         char(1)         not null,
   avg_row_length     {0}             not null,
   row_count          decimal(13)     not null,
   chained_row_count  decimal(13)     not null,
   avg_free_space     {0}             not null,
   avg_freelist_sp    {0}             not null,
   discovered_time    {3}             not null,
   removed_time       {3}             not null) {22} 
;


create table t_stat_segment
  (statistic_id       {0}             not null,
   statistic_type     char(1)         not null,
   creator_id         {0}             not null,
   tablespace_id      {0}             not null,
   oid                {0}             not null,
   name               varchar(128)    not null,
   {20}               varchar(128)    not null,
   tablespace         varchar(128)    not null,
   segment_type       {1}             not null,
   extents            {0}             not null,
   initial_extent     {0}             not null,
   next_extent        {0}             not null,
   min_extents        {0}             not null,
   max_extents        {0}             not null,
   pct_increase       {1}             not null,
   total_size         decimal(13)     not null,
   unused_space       decimal(13)     not null,
   freelist_blocks    {0}             not null,
   freelist_groups    {1}             not null,
   parent_creator_id  {0}             not null,
   parent_name        varchar(128)    not null,
   parent_type        char(1)         not null) {22} 
;


create table t_stat_dep_table
  (table_id           {0}             not null, 
   segment_oid        {0}             not null,
   {20}               varchar(128)    not null,
   pct_free           {1}             not null,
   pct_used           {1}             not null,
   ini_transactions   {1}             not null,
   max_transactions   {1}             not null,
   analyze_time       {3}             not null,
   user_stats         char(1)         not null,
   row_count          decimal(13)     not null,
   chained_row_count  decimal(13)     not null,
   avg_row_length     {0}             not null,
   avg_free_space     {0}             not null,
   avg_freelist_sp    {0}             not null) {22} 
;


create table t_stat_db_summary
  (tablespace_id      {0}             not null,
   statistic_id       {0}             not null,
   total_size         decimal(13)     not null,
   unused_space       decimal(13)     not null,
   freelist_blocks    decimal(13)     not null,
   table_count        {0}             not null,
   index_count        {0}             not null,
   other_count        {0}             not null) {22} 
;


create table t_res_table_filter
  (group_id           {0}             not null,
   filter_id          {0}             not null,
   computer_id        {0}             not null,
   database_id        {0}             not null,
   table_creator      varchar(128)    not null,
   table_name         varchar(128)    not null) {22} 
;

create table t_stat_db_sum_hist
  (object_id          {0}             not null,
   statistic_id       {0}             not null,
   statistic_type     char(1)         not null,
   statistic_time     {3}             not null,
   accum_count        {1}             not null,
   object_count       decimal(13)     not null,
   total_size         decimal(18)     not null,
   unused_space       decimal(18)     not null) {22} 
;

create unique index t_res_rdbms_ix
  on t_res_rdbms (computer_id, rdbms_name, rdbms_type)
;

create index t_res_db_ix
  on t_res_database (rdbms_id)
;

create unique index t_res_db_ix2
  on t_res_database (database_id)
;

create index t_res_ts_ix
  on t_res_tablespace (database_id)
;

create unique index t_res_ts_ix2
  on t_res_tablespace (tablespace_id)
;

create index t_res_df_ix
  on t_res_datafile (tablespace_id)
;

create index t_res_lg_ix 
  on t_res_log_group (database_id)
;

create unique index t_res_lg_ix2 
  on t_res_log_group (id)
;

create index t_res_lf_ix
  on t_res_logfile (database_id)
;

create index t_res_cf_id
  on t_res_controlfile (database_id)
;

create index t_res_arch_ld_ix
  on t_res_arch_log_dir (database_id)
;

create unique index t_res_arch_ld_ix2
  on t_res_arch_log_dir (directory_id)
;

create index t_stat_table_ix
  on t_stat_table (statistic_id, tablespace_id)
;

create index t_stat_seg_ix
  on t_stat_segment (tablespace_id, statistic_id, statistic_type)
;

create index t_stat_dep_tb_ix
  on t_stat_dep_table (table_id, segment_oid)
;

create index t_stat_db_sum_ix
  on t_stat_db_summary (tablespace_id, statistic_id)
;

create index t_stat_db_sumh_ix
  on t_stat_db_sum_hist (object_id, statistic_id, statistic_type)
;

create index t_res_tbfilt_ix 
  on t_res_table_filter (group_id)
;

create index t_res_tbfilt_ix2 
  on t_res_table_filter (computer_id, database_id)
;

insert into t_stat_definition values
   (25, 'Tivoli', '{72}',
    '{34}',
    0, 'Tivoli', '5', -1,
    0, 0, 0, 0, 0, 0, '0', '0', '1', '0', '0', '0', '0', '0', 7, 4, 2, {9})
;
insert into t_stat_definition values
   (26, 'Tivoli', '{73}',
    '{35}',
    0, 'Tivoli', '5', -1,
    0, 20, 0, 0, 0, 0, '0', '0', '0', '0', '0', '0', '0', '0', 0, 0, 0, {9})
;
insert into t_stat_definition values
   (27, 'Tivoli', '{74}',
    '{36}',
    0, 'Tivoli', '5', -1,
    0, 0, 0, 0, 0, 0, '1', '0', '0', '0', '0', '0', '0', '0', 7, 4, 2, {9})
;
insert into t_stat_definition values
   (28, 'Tivoli', '{75}',
    '{37}',
    0, 'Tivoli', '5', -1,
    20, 0, 0, 0, 0, 0, '0', '0', '0', '0', '0', '0', '0', '0', 0, 0, 0, {9})
;
insert into t_stat_definition values
   (29, 'Tivoli', '{76}',
    '{38}',
    0, 'Tivoli', '5', -1,
    0, 0, 20, 0, 0, 0, '0', '0', '0', '0', '0', '0', '0', '0', 0, 0, 0, {9})
;

insert into t_group values
  (5, 'Tivoli', '{77}', 
   '{39}', 0,
   'Tivoli', '1', 48, 0)
;

insert into t_alert_definition values
   (106, 'Tivoli', '{78}', '{40}', 0, 'Tivoli',
    '1', 2, 11, 33, '0', -1, '0', '0', '0', '8', '0', ' ', -1, ' ')
;
insert into t_schedule values
   (106, 'Tivoli', '{78}', '{41)', 0,
    'Tivoli', '1', '3', 2001, 6, 1, 0, 0, '1', '3', 1, '0', '0', '0',
    '0', '0', '0', '0', '1', '1', ' ', ' ', 106, 'A', 0, -1)
;
insert into t_res_attribute values
   (4, 0, 106, 39, '0')
;

insert into t_alert_definition values
   (107, 'Tivoli', '{79}', '{42}', 0, 'Tivoli', 
    '1', 2, 13, 40, '0', -1, '0', '0', '0', '8', '0', ' ', -1, ' ')
;
insert into t_schedule values
   (107, 'Tivoli', '{79}', '{43}', 0,
    'Tivoli', '1', '3', 2001, 6, 1, 0, 30, '1', '3', 1, '0', '0', '0',
    '0', '0', '0', '0', '1', '1', ' ', ' ', 107, 'B', 0, -1)
;
insert into t_res_attribute values
   (5, 48, 107, 40, '0')
;
insert into t_res_attribute values
   (25, 41, 107, 40, '0')
;
insert into t_res_attribute values
   (26, 41, 107, 40, '0')
;
insert into t_res_attribute values
   (27, 41, 107, 40, '0')
;
insert into t_res_attribute values
   (28, 41, 107, 40, '0')
;
insert into t_res_attribute values
   (29, 41, 107, 40, '0')
;